@@ -69,7 +69,6 @@ function m.open(uri)
         cache = {},
     }
     m.onWatch('open', uri)
-    m.addRef(uri)
 end
 
 --- 关闭文件
@@ -81,7 +80,9 @@ function m.close(uri)
         file.trusted = false
     end
     m.onWatch('close', uri)
-    m.delRef(uri)
+    if (file._ref or 0) <= 0 and not m.isOpen(uri) then
+        m.remove(uri)
+    end
 end
 
 --- 是否打开
@@ -380,7 +381,7 @@ function m.delRef(uri)
     end
     file._ref = (file._ref or 0) - 1
     log.debug('del ref', uri)
-    if file._ref <= 0 then
+    if file._ref <= 0 and not m.isOpen(uri) then
         m.remove(uri)
     end
 end
@@ -661,13 +662,10 @@ end
 ---@param uri uri
 ---@return boolean
 function m.isLua(uri)
-    local ext = uri:match '%.([^%.%/%\\]+)$'
-    if not ext then
-        return false
-    end
-    if ext == 'lua' then
+    if util.stringEndWith(uri:lower(), '.lua') then
         return true
     end
+    -- check customed assoc, e.g. `*.lua.txt = *.lua`
     local matcher = m.getAssoc(uri)
     local path = furi.decode(uri)
     return matcher(path)
