@@ -570,8 +570,6 @@ function parseType(parent)
         type    = 'doc.type',
         parent  = parent,
         types   = {},
-        enums   = {},
-        resumes = {},
     }
     while true do
         local tp, content = peekToken()
@@ -617,7 +615,7 @@ function parseType(parent)
                 parent = result,
                 [1]    = content,
             }
-            result.enums[#result.enums+1] = typeEnum
+            result.types[#result.types+1] = typeEnum
             if not result.start then
                 result.start = typeEnum.start
             end
@@ -670,22 +668,23 @@ function parseType(parent)
             if currentRow < nextCommRow then
                 return false
             end
-            if nextComm.text:sub(1, 2) == '-@' then
+            if nextComm.text:match '^%-%s*%@' then
                 return false
             else
-                if nextComm.text:sub(1, 2) == '-|' then
+                local resumeHead = nextComm.text:match '^%-%s*%|'
+                if resumeHead then
                     NextComment(i)
                     row = row + i + 1
-                    local finishPos = nextComm.text:find('#', 3) or #nextComm.text
-                    parseTokens(nextComm.text:sub(3, finishPos), nextComm.start + 3)
+                    local finishPos = nextComm.text:find('#', #resumeHead + 1) or #nextComm.text
+                    parseTokens(nextComm.text:sub(#resumeHead + 1, finishPos), nextComm.start + #resumeHead + 1)
                     local resume = parseResume(result)
                     if resume then
                         if comments then
                             resume.comment = table.concat(comments, '\n')
                         else
-                            resume.comment = nextComm.text:match('#%s*(.+)', 3)
+                            resume.comment = nextComm.text:match('#%s*(.+)', #resumeHead + 1)
                         end
-                        result.resumes[#result.resumes+1] = resume
+                        result.types[#result.types+1] = resume
                         result.finish = resume.finish
                     end
                     comments = nil
@@ -717,7 +716,7 @@ function parseType(parent)
         while pushResume() do end
     end
 
-    if #result.types == 0 and #result.enums == 0 and #result.resumes == 0 then
+    if #result.types == 0 then
         pushWarning {
             type   = 'LUADOC_MISS_TYPE_NAME',
             start  = getFinish(),
