@@ -61,26 +61,30 @@ m.attributes = {}
 function m.register(method)
     return function (attrs)
         m.attributes[method] = attrs
+        if attrs.preview and not PREVIEW then
+            return
+        end
+        if attrs.capability then
+            cap.filling(attrs.capability)
+        end
         proto.on(method, attrs[1])
     end
 end
 
-filewatch.event(function (changes) ---@async
-    for _, change in ipairs(changes) do
-        if (CONFIGPATH and util.stringEndWith(change.path, CONFIGPATH)) then
-            for _, scp in ipairs(workspace.folders) do
-                local configPath = workspace.getAbsolutePath(scp.uri, CONFIGPATH)
-                if change.path == configPath then
-                    updateConfig(scp.uri)
-                end
+filewatch.event(function (ev, path) ---@async
+    if (CONFIGPATH and util.stringEndWith(path, CONFIGPATH)) then
+        for _, scp in ipairs(workspace.folders) do
+            local configPath = workspace.getAbsolutePath(scp.uri, CONFIGPATH)
+            if path == configPath then
+                updateConfig(scp.uri)
             end
         end
-        if util.stringEndWith(change.path, '.luarc.json') then
-            for _, scp in ipairs(workspace.folders) do
-                local rcPath     = workspace.getAbsolutePath(scp.uri, '.luarc.json')
-                if change.path == rcPath then
-                    updateConfig(scp.uri)
-                end
+    end
+    if util.stringEndWith(path, '.luarc.json') then
+        for _, scp in ipairs(workspace.folders) do
+            local rcPath     = workspace.getAbsolutePath(scp.uri, '.luarc.json')
+            if path == rcPath then
+                updateConfig(scp.uri)
             end
         end
     end
@@ -103,7 +107,7 @@ m.register 'initialize' {
         end
 
         return {
-            capabilities = cap.getIniter(),
+            capabilities = cap.getProvider(),
             serverInfo   = {
                 name    = 'sumneko.lua',
             },
@@ -221,8 +225,13 @@ m.register 'workspace/didRenameFiles' {
 m.register 'textDocument/didOpen' {
     ---@async
     function (params)
-        local doc   = params.textDocument
-        local uri   = files.getRealUri(doc.uri)
+        local doc    = params.textDocument
+        local scheme = furi.split(doc.uri)
+        if scheme ~= 'file' then
+            return
+        end
+        local uri    = files.getRealUri(doc.uri)
+        log.debug('didOpen', uri)
         workspace.awaitReady(uri)
         local text  = doc.text
         files.setText(uri, text, true, function (file)
@@ -263,6 +272,9 @@ m.register 'textDocument/didChange' {
 }
 
 m.register 'textDocument/hover' {
+    capability = {
+        hoverProvider = true,
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -301,6 +313,9 @@ m.register 'textDocument/hover' {
 }
 
 m.register 'textDocument/definition' {
+    capability = {
+        definitionProvider = true,
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -340,6 +355,9 @@ m.register 'textDocument/definition' {
 }
 
 m.register 'textDocument/typeDefinition' {
+    capability = {
+        typeDefinitionProvider = true,
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -379,6 +397,9 @@ m.register 'textDocument/typeDefinition' {
 }
 
 m.register 'textDocument/references' {
+    capability = {
+        referencesProvider = true,
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -406,10 +427,14 @@ m.register 'textDocument/references' {
 }
 
 m.register 'textDocument/documentHighlight' {
-    abortByFileUpdate = true,
+    capability = {
+        documentHighlightProvider = true,
+    },
+    ---@async
     function (params)
         local core = require 'core.highlight'
         local uri  = files.getRealUri(params.textDocument.uri)
+        workspace.awaitReady(uri)
         if not files.exists(uri) then
             return nil
         end
@@ -430,6 +455,11 @@ m.register 'textDocument/documentHighlight' {
 }
 
 m.register 'textDocument/rename' {
+    capability = {
+        renameProvider = {
+            prepareProvider = true,
+        },
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -633,6 +663,11 @@ m.register 'completionItem/resolve' {
 }
 
 m.register 'textDocument/signatureHelp' {
+    capability = {
+        signatureHelpProvider = {
+            triggerCharacters = { '(', ',' },
+        },
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -679,6 +714,9 @@ m.register 'textDocument/signatureHelp' {
 }
 
 m.register 'textDocument/documentSymbol' {
+    capability = {
+        documentSymbolProvider = true,
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -725,6 +763,17 @@ m.register 'textDocument/documentSymbol' {
 }
 
 m.register 'textDocument/codeAction' {
+    capability = {
+        codeActionProvider = {
+            codeActionKinds = {
+                '',
+                'quickfix',
+                'refactor.rewrite',
+                'refactor.extract',
+            },
+            resolveProvider = false,
+        },
+    },
     abortByFileUpdate = true,
     function (params)
         local core        = require 'core.code-action'
@@ -759,6 +808,17 @@ m.register 'textDocument/codeAction' {
 }
 
 m.register 'workspace/executeCommand' {
+    capability = {
+        executeCommandProvider = {
+            commands = {
+                'lua.removeSpace',
+                'lua.solve',
+                'lua.jsonToLua',
+                'lua.setConfig',
+                'lua.autoRequire',
+            },
+        },
+    },
     ---@async
     function (params)
         local command = params.command:gsub(':.+', '')
@@ -782,6 +842,9 @@ m.register 'workspace/executeCommand' {
 }
 
 m.register 'workspace/symbol' {
+    capability = {
+        workspaceSymbolProvider = true,
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
@@ -813,10 +876,30 @@ m.register 'workspace/symbol' {
     end
 }
 
+local function toArray(map)
+    local array = {}
+    for k in pairs(map) do
+        array[#array+1] = k
+    end
+    table.sort(array, function (a, b)
+        return map[a] < map[b]
+    end)
+    return array
+end
+
 m.register 'textDocument/semanticTokens/full' {
-    abortByFileUpdate = true,
+    capability = {
+        semanticTokensProvider = {
+            legend = {
+                tokenTypes     = toArray(define.TokenTypes),
+                tokenModifiers = toArray(define.TokenModifiers),
+            },
+            full  = true,
+        },
+    },
     ---@async
     function (params)
+        log.debug('textDocument/semanticTokens/full')
         local uri = files.getRealUri(params.textDocument.uri)
         workspace.awaitReady(uri)
         local _ <close> = progress.create(scope.getScope(uri), lang.script.WINDOW_PROCESSING_SEMANTIC_FULL, 0.5)
@@ -829,6 +912,15 @@ m.register 'textDocument/semanticTokens/full' {
 }
 
 m.register 'textDocument/semanticTokens/range' {
+    capability = {
+        semanticTokensProvider = {
+            legend = {
+                tokenTypes     = toArray(define.TokenTypes),
+                tokenModifiers = toArray(define.TokenModifiers),
+            },
+            range = true,
+        },
+    },
     ---@async
     function (params)
         log.debug('textDocument/semanticTokens/range')
@@ -845,11 +937,14 @@ m.register 'textDocument/semanticTokens/range' {
 }
 
 m.register 'textDocument/foldingRange' {
-    abortByFileUpdate = true,
+    capability = {
+        foldingRangeProvider = true,
+    },
     ---@async
     function (params)
         local core    = require 'core.folding'
         local uri     = files.getRealUri(params.textDocument.uri)
+        workspace.awaitReady(uri)
         if not files.exists(uri) then
             return nil
         end
@@ -916,7 +1011,89 @@ m.register '$/status/click' {
     end
 }
 
+m.register 'textDocument/formatting' {
+    capability = {
+        documentFormattingProvider = true,
+    },
+    preview = true,
+    ---@async
+    function(params)
+        local uri = files.getRealUri(params.textDocument.uri)
+
+        if not files.exists(uri) then
+            return nil
+        end
+
+        if not config.get(uri, 'Lua.format.enable') then
+            return nil
+        end
+
+        local pformatting = require 'provider.formatting'
+        pformatting.updateConfig(uri)
+
+        local core = require 'core.formatting'
+        local edits = core(uri, params.options)
+        if not edits or #edits == 0 then
+            return nil
+        end
+
+        local results = {}
+        for i, edit in ipairs(edits) do
+            results[i] = {
+                range   = converter.packRange(uri, edit.start, edit.finish),
+                newText = edit.text,
+            }
+        end
+
+        return results
+    end
+}
+
+m.register 'textDocument/rangeFormatting' {
+    capability = {
+        documentRangeFormattingProvider = true,
+    },
+    preview = true,
+    ---@async
+    function(params)
+        local uri = files.getRealUri(params.textDocument.uri)
+
+        if not files.exists(uri) then
+            return nil
+        end
+
+        if not config.get(uri, 'Lua.format.enable') then
+            return nil
+        end
+
+        local pformatting = require 'provider.formatting'
+        pformatting.updateConfig(uri)
+
+        local core = require 'core.rangeformatting'
+        local edits = core(uri, params.range, params.options)
+        if not edits or #edits == 0 then
+            return nil
+        end
+
+        local results = {}
+        for i, edit in ipairs(edits) do
+            results[i] = {
+                range   = converter.packRange(uri, edit.start, edit.finish),
+                newText = edit.text,
+            }
+        end
+
+        return results
+    end
+}
+
 m.register 'textDocument/onTypeFormatting' {
+    capability = {
+        documentOnTypeFormattingProvider = {
+            firstTriggerCharacter = '\n',
+            moreTriggerCharacter  = nil, -- string[]
+        },
+    },
     abortByFileUpdate = true,
     ---@async
     function (params)
